==> haskell-parser-combinators-0.4.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-parser-combinators.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parser-combinators
version: 0.4.0
id: parser-combinators-0.4.0-LXzRXKyLrFT6DPfieme8NK
key: parser-combinators-0.4.0-LXzRXKyLrFT6DPfieme8NK
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/parser-combinators
synopsis: Lightweight package providing commonly useful parser combinators
description:
    Lightweight package providing commonly useful parser combinators.
category: Parsing
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Applicative.Combinators
    Control.Applicative.Combinators.NonEmpty
    Control.Applicative.Permutations Control.Monad.Combinators
    Control.Monad.Combinators.NonEmpty
abi: 143b8a07a279a03d6bd71cc12928bb67
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/parser-combinators-0.4.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/parser-combinators-0.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/parser-combinators-0.4.0
hs-libraries: HSparser-combinators-0.4.0-LXzRXKyLrFT6DPfieme8NK
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-parser-combinators/html/parser-combinators.haddock
haddock-html: /usr/share/doc/haskell-parser-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parser-combinators-1.0.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-parser-combinators.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parser-combinators
version: 1.0.0
id: parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci
key: parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/parser-combinators
synopsis: Lightweight package providing commonly useful parser combinators
description:
    Lightweight package providing commonly useful parser combinators.
category: Parsing
abi: 7f9925423ee321de0651ba5e24e000f1
exposed: True
exposed-modules:
    Control.Applicative.Combinators
    Control.Applicative.Combinators.NonEmpty
    Control.Applicative.Permutations Control.Monad.Combinators
    Control.Monad.Combinators.Expr Control.Monad.Combinators.NonEmpty
import-dirs: /usr/lib/ghc-8.4.3/site-local/parser-combinators-1.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/parser-combinators-1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/parser-combinators-1.0.0
hs-libraries: HSparser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-parser-combinators/html/parser-combinators.haddock
haddock-html: /usr/share/doc/haskell-parser-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
